@@ -318,19 +318,21 @@ class JsonList(list):
                 l.append(vars(i)[m])
         return l
 
-    def where(self, m: str, v, o="=="):
+    def where(self, m: str, v, o: str="=="):
         d = {}
         if type(v) is str:
-            exec("def criteria(i): return i.%s %s '%s'" % (m, o, v), d)
+            criteria = "def criteria(i): return i.%s %s '%s'" % (m, o, v)
         elif isinstance(v, JsonObject):
-            exec("def criteria(i): return str(i.%s) %s '%s'" % (m, o, str(v)), d)
+            criteria = "def criteria(i): return str(i.%s) %s '%s'" % (m, o, str(v))
         else:
-            exec("def criteria(i): return i.%s %s %s" % (m, o, str(v)), d)
+            criteria = "def criteria(i): return i.%s %s %s" % (m, o, str(v))
 
+        exec(criteria, d)
         return self.filter(d["criteria"])
 
+
     def split_by(self, m) -> dict:
-        if type(m) is str:
+        if type(m) is str and issubclass(self.list_type, JsonObject) :
             d = {}
             exec("def criteria(i): return i.%s" % m, d)
             m = d["criteria"]
